==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection.md <==
# AmazonVpcVpnConnection


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')
```



| Illustration | AmazonVpcVpnConnection | AmazonVpcVpnConnectionCard | AmazonVpcVpnConnectionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection.png) | ![illustration for AmazonVpcVpnConnection](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection.Local.png) | ![illustration for AmazonVpcVpnConnectionCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnectionCard.Local.png) | ![illustration for AmazonVpcVpnConnectionGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnectionGroup.Local.png) |




## AmazonVpcVpnConnection

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnection
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnection('AmazonVpcVpnConnection', 'Amazon Vpc Vpn Connection', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnection
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnection('AmazonVpcVpnConnection', 'Amazon Vpc Vpn Connection', 'an optional tech label')
@enduml
```

## AmazonVpcVpnConnectionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionCard('AmazonVpcVpnConnectionCard', 'Amazon Vpc Vpn Connection Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionCard('AmazonVpcVpnConnectionCard', 'Amazon Vpc Vpn Connection Card', 'an optional description')
@enduml
```

## AmazonVpcVpnConnectionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionGroup('AmazonVpcVpnConnectionGroup', 'Amazon Vpc Vpn Connection Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionGroup('AmazonVpcVpnConnectionGroup', 'Amazon Vpc Vpn Connection Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection.md <==
# AmazonVpcVpnConnection


```text
aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection
```

```text
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')
```



| Illustration | AmazonVpcVpnConnection | AmazonVpcVpnConnectionCard | AmazonVpcVpnConnectionGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection.png) | ![illustration for AmazonVpcVpnConnection](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection.Local.png) | ![illustration for AmazonVpcVpnConnectionCard](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnectionCard.Local.png) | ![illustration for AmazonVpcVpnConnectionGroup](../../../aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnectionGroup.Local.png) |




## AmazonVpcVpnConnection

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnection
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnection('AmazonVpcVpnConnection', 'Amazon Vpc Vpn Connection', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnection
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnection('AmazonVpcVpnConnection', 'Amazon Vpc Vpn Connection', 'an optional tech label')
@enduml
```

## AmazonVpcVpnConnectionCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionCard('AmazonVpcVpnConnectionCard', 'Amazon Vpc Vpn Connection Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionCard
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionCard('AmazonVpcVpnConnectionCard', 'Amazon Vpc Vpn Connection Card', 'an optional description')
@enduml
```

## AmazonVpcVpnConnectionGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionGroup('AmazonVpcVpnConnectionGroup', 'Amazon Vpc Vpn Connection Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonVpcVpnConnectionGroup
include('aws-q3-2021/Resource/NetworkingAndContentDelivery/AmazonVpcVpnConnection')

' renders the element
AmazonVpcVpnConnectionGroup('AmazonVpcVpnConnectionGroup', 'Amazon Vpc Vpn Connection Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
